"""
Example: Setup Rate Calculator using EShopBox SDK
"""

import os
from eshopbox.client import EShopBoxSDK
from dotenv import load_dotenv

load_dotenv()


def rate_calculator(sdk):
    payload = {
        "journeyType": "forward",
        "pickupPincode": "160071",
        "dropPincode": "247342",
        "orderWeight": "500",
        "length": "12",
        "width": "12",
        "height": "33",
        "paymentMethod": "Prepaid",
        "doorstepQc": False,
    }
    response = sdk.rate_calculator.calculate(payload)
    print("Response: ", response)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv("ESHOPBOX_WORKSPACE", ""),
        client_id=os.getenv("ESHOPBOX_CLIENT_ID", ""),
        client_secret=os.getenv("ESHOPBOX_SECRET_ID", ""),
        refresh_token=os.getenv("ESHOPBOX_REFRESH_TOKEN", ""),
    )
    rate_calculator(sdk)


if __name__ == "__main__":
    main()



"""Version information for EShopBox SDK"""

__version__ = "1.1.7"
__author__ = "Sakib Mailk"
__email__ = "sakibwis.wis@gmail.com"
__license__ = "MIT"
__description__ = "Python SDK for EShopBox Shipping APIs"
__url__ = "https://github.com/sakib-wis/eshopbox-sdk"



"""EShopBox Python SDK - A comprehensive package for EShopBox shipping APIs"""

from eshopbox.__version__ import __version__
from eshopbox.client import EShopBoxSDK
from eshopbox.exceptions import (
    EShopBoxException,
    AuthenticationError,
    APIError,
    ValidationError,
    RateLimitError,
    NotFoundError,
)

__all__ = [
    "EShopBoxSDK",
    "EShopBoxException",
    "AuthenticationError",
    "APIError",
    "ValidationError",
    "RateLimitError",
    "NotFoundError",
    "__version__",
]



import redis

r = redis.Redis(host="localhost", port=6379, decode_responses=True)


class TokenCache:
    def __init__(self):
        self.redis_client = r
        self.expires_in = 2592000  # 30 days

    def get_token(self, key):
        return self.redis_client.get(key) or None

    def set_token(self, key, token):
        self.redis_client.setex(key, self.expires_in, token)



"""
Example: Manage Inventory using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv

load_dotenv()


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv("ESHOPBOX_WORKSPACE", ""),
        client_id=os.getenv("ESHOPBOX_CLIENT_ID", ""),
        client_secret=os.getenv("ESHOPBOX_SECRET_ID", ""),
        refresh_token=os.getenv("ESHOPBOX_REFRESH_TOKEN", ""),
    )

    sku = "SKU1234"

    print(f"Fetching inventory for {sku}...")
    inventory = sdk.inventory.get_stock(sku)
    print("Current stock:", inventory)

    print(f"Updating inventory for {sku}...")
    update_payload = {"sku": sku, "quantity": 25}

    updated = sdk.inventory.update_stock(update_payload)
    print("Updated stock:", updated)


if __name__ == "__main__":
    main()
